@@ -315,7 +315,7 @@ class SFREAD:
                     if nend is not None:
                         bytlen = (nend - nbeg)*np.prod(shape_arr[:-1])*type_len
                         shape_arr[-1] = nend - nbeg
-                print(bytlen, np.prod(shape_arr), type_len, addr)
+
                 data = np.ndarray(shape_arr, '>%s' %sfmt, self.getchunk(addr, bytlen), order='F')
 
 # LongLong in [ns] and no zero at TS06
@@ -451,6 +451,7 @@ class SFREAD:
         pset = str_byt.to_str(pset)
         sfo = self.sfh[pset]
         otyp = sfo.obj_type
+        logger.debug('PSET %s, oytp %d', pset, otyp)
         if otyp not in (Device, ParamSet):
             return None
 
@@ -458,8 +459,8 @@ class SFREAD:
 
         j0 = 0
         par_d = {}
-        logger.debug('Diag: %s, PS: %s, addr: %d, length: %d', self.diag, pset, sfo.items, sfo.length)
-        for j in range(sfo.items):
+        logger.debug('Diag: %s, PS: %s, addr: %d, length: %d', self.diag, pset, sfo.nitems, sfo.length)
+        for j in range(sfo.nitems):
             pname = str_byt.to_str(buf[j0: j0+8])
             unit, dfmt, n_items = unpack('>3h', buf[j0+8:  j0+14])
             meta = type('', (), {})()
@@ -513,7 +514,7 @@ class SFREAD:
             return None
         buf = self.getchunk(sfo.address, sfo.length)
         sfmt = sfdics.fmt2struc[dfmt]
-        list_ids = unpack('>%d%s' %(sfo.items, sfmt), buf)
+        list_ids = unpack('>%d%s' %(sfo.nitems, sfmt), buf)
 
         return [self.getobjname(jid) for jid in list_ids]
 
