@@ -168,7 +168,7 @@ class WW:
             return {'items': items.value, 'format': format.value}
 
 
-    def SetObject(self, signame, data, tim_axis=0):
+    def SetObject(self, signame, data, tim_axis=None):
         """Stores 'data'-array of a given object named 'signame' of type 
         Signal, SigGroup or Areabase to the target shotfile
         """
@@ -300,7 +300,7 @@ class WW:
         return True
 
 
-    def SetAreabase(self, areaname, data, sizes=None, tim_axis=0):
+    def SetAreabase(self, areaname, data, sizes=None, tim_axis=None):
         """Stores 'data'-array of a given Areabase named 'areaname'
         to the target shotfile
         """
@@ -321,23 +321,23 @@ class WW:
                 return
 
             if data.ndim > 2:
-                logger.error('AB %s hat %d dims: only a time and a space dependence are allowed, flatten the AB space-data', areaname, data.ndim)
+                logger.error('AB %s hat %d dims: only a time and a space dependence are allowed, flatten the space data', areaname, data.ndim)
                 return
 
+            if sizes is not None:
+                nx = len(sizes)
+                csizes[:nx] = sizes[:nx]
+
             if tim_axis is None:
                 nt = 1
                 if sizes is None:
                     csizes[0] = data.shape[0]
-                else:
-                    nx = len(sizes)
-                    csizes[:nx] = sizes[:nx]
             else:
-                nt = data.shape[tim_axis]
+                if tim_axis == 0:
+                    data = data.T
+                nt = data.shape[1]
                 if sizes is None:
-                    csizes[:data.ndim-1] = np.delete(data.shape, tim_axis)[:data.ndim-1]
-                else:
-                    nx = len(sizes)
-                    csizes[:nx] = sizes[:nx]
+                    csizes[0] = data.shape[0]
 
             logger.debug('AB %s, %d, %d, %d, %d, %d', areaname, sf_dtype, nt, *csizes)
 
